#
# spec file for package libcotp
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libsoname %{name}2
%if 0%{?fedora_version}
%global debug_package %{nil}
%endif
Name:           libcotp
Version:        2.0.1
Release:        1.1
Summary:        C library for generating TOTP and HOTP
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            https://github.com/paolostivanin/%{name}
Source0:        https://github.com/paolostivanin/%{name}/archive/v%{version}.tar.gz
Source1:        https://github.com/paolostivanin/libcotp/releases/download/v%{version}/v%{version}.tar.gz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  libgcrypt-devel
BuildRequires:  pkgconfig
Obsoletes:      libbaseencode <= 1.0.15

%description
%{name} C library for generating TOTP and HOTP according to RFC-6238.
It supports custom digits, (3 to 10) custom period (1 to 120 seconds) and
also Steam TOTP format.

%package -n     %{libsoname}
Summary:        C library for generating TOTP and HOTP
Group:          System/Libraries

%description -n %{libsoname}
%{name} C library for generating TOTP and HOTP according to RFC-6238.
It supports custom digits, (3 to 10) custom period (1 to 120 seconds) and
also Steam TOTP format.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libsoname} = %{version}

%description    devel
Pkg-config and header files for developing applications that use %{name}

%prep
%autosetup -p1

%build
%cmake
%cmake_build

%install
%cmake_install

%post -n        %{libsoname} -p /sbin/ldconfig
%postun -n      %{libsoname} -p /sbin/ldconfig

%files -n %{libsoname}
%{_libdir}/*.so.*

%files devel
%{_libdir}/*.so
%{_includedir}/*
%{_libdir}/pkgconfig/cotp.pc

%changelog
* Tue May  2 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.0.1:
  * If execution runs fine, set err_code to NO_ERROR in get_totp_at,
    get_steam_totp_at and otp_to_int.
- Revert AVX2 change.
* Wed Mar  8 2023 Paolo Stivanin <info@paolostivanin.com>
- Build AVX2 enabled hwcaps library for x86_64-v3
* Wed Feb  1 2023 Paolo Stivanin <info@paolostivanin.com>
- Drop libbaseencode dep, since it's no longer necessary and obsolete it
- Fix changelog typo
* Tue Jan 31 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0.0:
  * In particular, libbaseencode has been merged with libcotp, so now users
    can call base32 functions by just including `cotp.h`
  BREAKING CHANGES:
  * `totp_verify` has been removed
  * `hotp_verify` has been removed
  * `base64_encode` has been removed
  * `base64_decode` has been removed
  ADDED:
  * new API `otp_to_int`
  * `base32` encoding and decoding functions from libbaseencode
  * new tests for libcotp
  CHANGES:
  * the soversion is now set only from the `$major` version (e.g. `2`), and
    not from `$major$minor` (e.g. `12`) like it used to be.
* Sun Jan  8 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.2.8:
  * this release fixes a regression brought by v1.2.7.
* Thu Jan  5 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.2.7:
  * check return value for gcrypt functions
* Thu May 19 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.2.6:
  * fix pkg-config file generation (#32)
* Wed Dec 29 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to v1.2.4:
  * small fixes from PVS scan
  * tests: do no require installation to run tests
* Mon Apr 20 2020 Markos Chandras <markos@chandras.me>
- Disable debug package on Fedora (https://en.opensuse.org/Fedora_packaging)
* Tue Mar 17 2020 Paolo Stivanin <info@paolostivanin.com>
- run spec cleaner
* Tue Mar 12 2019 Paolo Stivanin <info@paolostivanin.com>
- Update to v1.2.2
  * add c++ support
* Sun Oct 21 2018 Paolo Stivanin <info@paolostivanin.com>
- Fix soname
* Sun Oct 21 2018 Paolo Stivanin <info@paolostivanin.com>
- Update libcotp to v1.2.1
* Sat Aug 25 2018 info@paolostivanin.com
- First release on OBS
